@@ -192,9 +192,9 @@ class Repository(metaclass=abc.ABCMeta):
 class EventPublisherRepository(Repository, metaclass=abc.ABCMeta):
     """Repository that publishes its saved events to domain event publisher."""
 
-    def __init__(self):  # noqa: D102
+    def __init__(self, publisher: ApplicationDomainEventPublisher):  # noqa: D102
         self.listeners = list()
-        self.register_listener(ApplicationDomainEventPublisher().instance)
+        self.register_listener(publisher)
 
     def save(self, obj: DomainObject) -> None:  # noqa: D102
         to_emit = self.append_to_stream(obj)
@@ -243,20 +243,19 @@ class EventPublisherRepository(Repository, metaclass=abc.ABCMeta):
         raise NotImplementedError()
 
 
-class MongoEventSourceRepository(
-    EventPublisherRepository, metaclass=abc.ABCMeta
-):
+class MongoEventSourceRepository(EventPublisherRepository, metaclass=abc.ABCMeta):
     """EventSource repository that persist event in mongodb."""
 
     def __init__(
         self,
+        publisher: ApplicationDomainEventPublisher,
         client,
         database="fenrys",
         collection="event_store",
         memento_collection="domain_object_mementos",
         logger=None,
     ):
-        super().__init__()
+        super().__init__(publisher)
         self.__client = client
         self.__db = self.__client[database]
         self.__collection = self.__db[collection]
@@ -272,9 +271,7 @@ class MongoEventSourceRepository(
         while True:
             try:
                 known_event_stream = self.get_event_stream_for(obj.object_id)
-                known_event_ids = [
-                    event["event_id"] for event in known_event_stream
-                ]
+                known_event_ids = [event["event_id"] for event in known_event_stream]
                 max_known_version = (
                     known_event_stream[-1]["version"]
                     if len(known_event_stream) > 0
@@ -410,7 +407,7 @@ class MongoEventSourceRepository(
         try:
             memento_payload = obj.get_memento()
             if not obj.is_json_serializable(memento_payload):
-                raise ValueError(f"Memento should be json serializable")
+                raise ValueError("Memento should be json serializable")
 
             memento = {
                 "object_id": obj.object_id,
@@ -429,10 +426,7 @@ class MongoEventSourceRepository(
         self.__memento_collection.delete_one({"object_id": object_id})
 
     def __have_memento(self, object_id):
-        return (
-            self.__memento_collection.count_documents({"object_id": object_id})
-            > 0
-        )
+        return self.__memento_collection.count_documents({"object_id": object_id}) > 0
 
     def __create_indexes(self):
         self.__collection.create_index(
@@ -457,11 +451,9 @@ class MongoEventSourceRepository(
             self.__logger.error(message)
 
 
-class InMemoryEventSourceRepository(
-    EventPublisherRepository, metaclass=abc.ABCMeta
-):
-    def __init__(self):
-        super().__init__()
+class InMemoryEventSourceRepository(EventPublisherRepository, metaclass=abc.ABCMeta):
+    def __init__(self, publisher: ApplicationDomainEventPublisher):
+        super().__init__(publisher)
         self.__repo = list()
 
     def append_to_stream(self, obj):
